%define prerelease 0
%define name dante
%define version 1.1.13
%define release 3mdk
%define prefix %{_prefix}

Summary: A free Socks v4/v5 client implementation
Name: dante
Version: %{version}
%if %{prerelease}
Release: 0.pre%{prerelease}.%{release}
%else
Release: %{release}
%endif
License: BSD-like
Group: Networking/Other
URL: http://www.inet.no/dante/
Buildroot: %{_tmppath}/%{name}-buildroot
Buildroot: %{_tmppath}/%{name}-buildroot
Buildrequires: perl-base pam-devel tcp_wrappers-devel binutils

%if %{prerelease}
Source: %{name}-%{version}-pre%{prerelease}.tar.gz
%else
Source: %{name}-%{version}.tar.gz
%endif
Patch1: dante-1.1.12-pre1-pam-syslog.patch.bz2

%description
Dante is a free implementation of the proxy protocols socks version 4,
socks version 5 (rfc1928) and msproxy. It can be used as a firewall
between networks. It is being developed by Inferno Nettverk A/S, a
Norwegian consulting company. Commercial support is available.

This package contains the dynamic libraries required to "socksify"
existing applications to become socks clients.

%package server
Summary: A free Socks v4/v5 server implementation
Group: System/Servers

%description server
This package contains the socks proxy daemon and its documentation.
The sockd is the server part of the Dante socks proxy package and
allows socks clients to connect through it to the network.

%package devel
Summary: Development libraries for socks
Group: Development/Other
Requires: dante = %{version}

%description devel
Additional libraries required to compile programs that use socks.

%prep
rm -rf $RPM_BUILD_ROOT

%if %{prerelease}
%setup -n %name-%version-pre%{prerelease}
%else
%setup -n %name-%version
%endif
%patch1 -p1

# This file is embedded here instead of being another source in order
# to the prefix directory
cat >sockd.init <<\EOF
#!/bin/sh
#
# sockd         This shell script takes care of starting and stopping
#               the Dante server.
#
# chkconfig: 2345 65 35
# description: sockd implements a socks v4/v5 proxy server

# Source function library.
. /etc/rc.d/init.d/functions

# Source networking configuration.
. /etc/sysconfig/network

# Check that networking is up.
[ "${NETWORKING}" = "no" ] && exit 0

[ -x /usr/sbin/sockd ] || exit 0

SOCKD_CONF="/etc/sockd.conf"
[ ! -f "$SOCKD_CONF" ] && exit 1

SOCKD_EXTRA_OPTIONS=
[ -f /etc/sysconfig/sockd ] && . /etc/sysconfig/sockd

RETVAL=0

start()
{
	gprintf "Starting sockd: "
	daemon /usr/sbin/sockd $SOCKD_EXTRA_OPTIONS -D -f $SOCKD_CONF
	RETVAL=$?
	echo
	[ "$RETVAL" = 0 ] && touch /var/lock/subsys/sockd
}

stop()
{
	gprintf "Shutting down sockd: "
	killproc sockd
	RETVAL=$?
	echo
	rm -f /var/lock/subsys/sockd
}

reload()
{
	gprintf "Reloading %s configuration:" "sockd"
	[ -f /var/run/sockd.pid ] && /bin/kill -HUP `cat /var/run/sockd.pid`
	RETVAL=$?
	echo
}


# See how we were called.
case "$1" in
  start)
	# Start daemons.
	start
	;;
  stop)
	# Stop daemons.
	stop
	;;
  restart)
	stop
	start
	;;
  condrestart)
	if [ -f /var/lock/subsys/sockd ]; then
		stop
		start
	fi
	;;
  reload )
	reload
  ;;
  status)
	status sockd
	;;
  *)
	gprintf "Usage: sockd {start|stop|restart|condrestart|reload|status}\n"
	exit 1
esac

exit "$RETVAL"
EOF

cat > sockd.sysconf << \EOF
# Any extra option to pass to sockd
SOCKD_EXTRA_OPTIONS=
EOF

%build

%configure2_5x --enable-debug

%make

%install
rm -rf ${RPM_BUILD_ROOT}

%makeinstall

#set library as executable - prevent ldd from complaining
chmod +x ${RPM_BUILD_ROOT}%{prefix}/lib/*.so.*.*

install -d ${RPM_BUILD_ROOT}/etc/rc.d/init.d
install -d ${RPM_BUILD_ROOT}/etc/sysconfig
install -d ${RPM_BUILD_ROOT}%{prefix}/bin

install -m 644 example/socks.conf ${RPM_BUILD_ROOT}/etc
install -m 644 example/sockd.conf ${RPM_BUILD_ROOT}/etc

install -m 755 sockd.init ${RPM_BUILD_ROOT}/etc/rc.d/init.d/sockd
install -m 644 sockd.sysconf ${RPM_BUILD_ROOT}/etc/sysconfig/sockd

#ln -sf %{prefix}/lib/libdsocks.so $RPM_BUILD_ROOT/%{prefix}/lib/libdsocks.so.0
#ln -sf %{prefix}/lib/libdsocks.so.0 $RPM_BUILD_ROOT/%{prefix}/lib/libdsocks.so

# lenny : 	remove cause it conflicts with glibc-devel
# 		a strace shows that a call is done to libdl.so
#ln -sf %{prefix}/lib/libdl.so.2 $RPM_BUILD_ROOT/%{prefix}/lib/libdl.so

# bor: comment libdl.so out it seems to work just fine without it
/usr/bin/perl -pe 's/(libdl\.so)//' -i ${RPM_BUILD_ROOT}/%{prefix}/bin/socksify

# bor: add explicit version to libdsocks
LIBDSOCKS=$(/usr/bin/objdump -p ${RPM_BUILD_ROOT}%{prefix}/lib/libdsocks.so | grep SONAME | awk '{print $2}') 
/usr/bin/perl -pe "s/(libdsocks\\.so)/$LIBDSOCKS/" -i ${RPM_BUILD_ROOT}/%{prefix}/bin/socksify


%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post server
%_post_service sockd

%preun server
%_preun_service sockd

%files
%defattr(-,root,root)
%doc BUGS CREDITS INSTALL LICENSE NEWS README SUPPORT TODO VERSION
%doc doc/README* doc/SOCKS4.protocol doc/faq* doc/rfc*
%_libdir/*.so.*
%_bindir/socksify
%_mandir/man5/socks.conf.5*
%config(noreplace) /etc/socks.conf

%files server
%defattr(-,root,root)
%_sbindir/sockd
%_mandir/man5/sockd.conf.5*
%_mandir/man8/*
%config(noreplace) /etc/sockd.conf
%config(noreplace)  /etc/rc.d/init.d/sockd
%config(noreplace)  /etc/sysconfig/sockd

%files devel
%defattr (-,root,root)
%_libdir/*.la
%_libdir/*.a
%_libdir/*.so
%_includedir/*.h

%changelog
* Tue Jan 28 2003 Lenny Cartier <lenny@mandrakesoft.com> 1.1.13-3mdk
- rebuild

* Tue Jun 18 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.13-2mdk
- fix documentation list

* Tue Jun 18 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.13-1mdk
- new version
- small spec tweaks to handle pre versions
- initscript cleanup
- sysconfig template - -l is obsolete, everything is line-buffered now.
- removed patch0, patch3, patch4 - intergrated upstream
- removed patch103 - different version upstream

* Fri Jun  7 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-6mdk
- patch103 - make sure logfiles are always linebuffered when requested
- dante-server does not depend on dante
- do not use range in %doc section to avoid locale problem
- add more file from doc/* to %doc section

* Wed May 15 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-5mdk
- fix compilation with gcc-3.1 (it requires correct syntax even if
code is under #ifdef)

* Fri Apr 19 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-4mdk
- patch3 - fix misinterpretation of %s in log output (Michael Shuldman)
- BuildRequires: remove bison

* Tue Apr 16 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-3mdk
- remove patch2 - not needed (stupid me)
- add /etc/sysconfig/sockd and SOCKD_EXTRA_OPTIONS
- patch0: remove "do-not-set-close-on-exec' hack, not needed
- use _post/_preun_service macros

* Mon Apr 15 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-2mdk
- patch2 (fflush log output to prevent log evaluation delays on low
  volume server)
- update patch0
    o initialize state.pid after fork, not before
    o do not set close-on-exec for logfiles in server
- BuildRequires: bison

* Fri Apr 12 2002 Andrej Borsenkow <arvidjaar@mail.ru> 1.1.12-1mdk
- BuildRequires: pam-devel tcp_wrappers-devel binutils
- use configure2_5x macro
- really add explicit version to libdsocks.so in socksify
- do not use libdl.so it seems to work fine without it
- libtool already creates libfoo.so link for us
- simplify quoting in /etc/rc.d/init.d/sockd
- workaround for gprintify.py bug (remove quotes around variable)
- patch0 (correct exit code)
- patch1 (workaround for PAM syslog implementation)
- 1.1.12

* Wed Feb 06 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-2mdk
- patch from Borsenkow Andrej <Andrej.Borsenkow@mow.siemens.ru> :
	o add explicit versions to libraries	

* Tue Feb 05 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-1mdk
- update to 1.1.11 final
- again fix in initscript 
  ( thx Borsenkow Andrej <Andrej.Borsenkow@mow.siemens.ru>)

* Tue Feb 05 2002 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.4mdk
- fixes initscript from Pascal Terjan <pascal.terjan@free.fr>

* Sat Nov 24 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.3mdk
- minor changes in initscript to be sure to use /etc/sockd.conf
- remove libdl for now
- some spec cleaning

* Fri Nov 23 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.2mdk
- 1.1.11pre2

* Tue Nov 13 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.11-0.1mdk
- 1.1.11pre1

* Wed Sep 05 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.10-2mdk
- links libdsocks.so.0, libdl.so.2, thx Thomas Poindessous

* Mon Jul 02 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.10-1mdk
- upgraded to 1.1.10

* Wed Mar 14 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.9-1mdk
- updated to 1.1.9

* Thu Feb 22 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.8-1mdk
- updated to 1.1.8

* Mon Jan 08 2001 Lenny Cartier <lenny@mandrakesoft.com> 1.1.6-1mdk
- updated to 1.1.6
- rebuild

* Tue Jun 13 2000 Lenny Cartier <lenny@mandrakesoft.com> 1.1.1-2mdk
- fix link on libdsocks

* Thu Jun 10 2000 Geoffrey Lee <snailtalk@linux-mandrake.com> 1.1.1-1mdk
- mandrake adaptations
- first release for mandrake

* Wed Mar 10 1999 Karl-Andre' Skevik <karls@inet.no>
- Integrated into CVS
- socksify patch no longer needed

* Thu Mar 04 1999 Oren Tirosh <oren@hishome.net>
- configurable %{prefix}, fixed daemon init script
- added /lib/libdl.so to socksify

* Wed Mar 03 1999 Oren Tirosh <oren@hishome.net>
- First spec file for Dante
